@@ -108,7 +108,7 @@ class Tail:
       return False
     if new_size > self.size:
       log('File size increased: check rotated')
-      old_pos = self.file.tell()
+      old_pos = self.pos
       self.file.seek(old_pos)
       bytes = self.file.read(1)
       if bytes is not None and len(bytes) > 0:
@@ -165,10 +165,10 @@ class Tail:
           self._open_if_log_rotated()
         self.file.seek(self.pos)
       else:
+        self.size += len(bytes)
         str = bytes.decode(self.charset)
         log('Read {0}', bytes)
         yield str
-        self.size += len(bytes)
         wait_interval = MIN_WAIT
 
 
